DROP PROCEDURE IF EXISTS audit_entry_addcolumn;

DELIMITER $$

CREATE PROCEDURE audit_entry_addcolumn()
BEGIN
	SET @database = (SELECT database()); 
	SET @cols = ( SELECT COUNT(*)
	               FROM INFORMATION_SCHEMA.COLUMNS
	               WHERE TABLE_SCHEMA=@database AND 
								       TABLE_NAME='audit_entry' AND 
											 COLUMN_NAME='new_value' );
	
	IF (@cols = 0) THEN
		/* Add new column `new_value` */
		ALTER TABLE `audit_entry` ADD COLUMN `new_value` longtext DEFAULT NULL;
	END IF;

	/* Adding new value to column depending on audit description for ALERT_SEVERITY_CHANGED
	   and ALERT_PRIORITY_CHANGED
	*/
	UPDATE `audit_entry` SET `new_value`="Critical" WHERE `audit_item`="ALERT_SEVERITY_CHANGED" AND `audit_desc` LIKE "%to 'Critical'%";
	UPDATE `audit_entry` SET `new_value`="Major" WHERE `audit_item`="ALERT_SEVERITY_CHANGED" AND `audit_desc` LIKE "%to 'Major'%";
	UPDATE `audit_entry` SET `new_value`="Minor" WHERE `audit_item`="ALERT_SEVERITY_CHANGED" AND `audit_desc` LIKE "%to 'Minor'%";
	UPDATE `audit_entry` SET `new_value`="Warning" WHERE `audit_item`="ALERT_SEVERITY_CHANGED" AND `audit_desc` LIKE "%to 'Warning'%";
	UPDATE `audit_entry` SET `new_value`="Informational" WHERE `audit_item`="ALERT_SEVERITY_CHANGED" AND `audit_desc` LIKE "%to 'Informational'%";
	UPDATE `audit_entry` SET `new_value`="Clear" WHERE `audit_item`="ALERT_SEVERITY_CHANGED" AND `audit_desc` LIKE "%to 'Clear'%";

	UPDATE `audit_entry` SET `new_value`="High" WHERE `audit_item`="ALERT_PRIORITY_CHANGED" AND `audit_desc` LIKE "%to 'High'%";
	UPDATE `audit_entry` SET `new_value`="Medium" WHERE `audit_item`="ALERT_PRIORITY_CHANGED" AND `audit_desc` LIKE "%to 'Medium'%";
	UPDATE `audit_entry` SET `new_value`="Low" WHERE `audit_item`="ALERT_PRIORITY_CHANGED" AND `audit_desc` LIKE "%to 'Low'%";
	UPDATE `audit_entry` SET `new_value`="" WHERE `audit_item`="ALERT_PRIORITY_CHANGED" AND `new_value` IS NULL;

END $$

DELIMITER ; 
CALL audit_entry_addcolumn();

DROP PROCEDURE IF EXISTS audit_entry_addcolumn;
